from random import choice

female_names = [
    'Abigail', 'Ada', 'Adaline', 'Adelaide', 'Adeline', 'Agatha', 'Agnes',
    'Alberta', 'Alexandria', 'Althea', 'Amaryllis', 'Amelia', 'Antoinette',
    'Arabella', 'Astrid', 'Augusta', 'Aurelia', 'Aurora', 'Beatrice', 'Bianca',
    'Calista', 'Camilla', 'Cecilia', 'Celeste', 'Charlotte', 'Clara', 'Clarissa',
    'Clementine', 'Constance', 'Cordelia', 'Corinne', 'Dahlia', 'Daisy', 'Daphne',
    'Delilah', 'Dorothea', 'Edith', 'Eleanor', 'Eliza', 'Eloise', 'Emmeline',
    'Estella', 'Eugenia', 'Euphemia', 'Evangeline', 'Faye', 'Felicity', 'Fern',
    'Fiona', 'Florence', 'Freya', 'Geneva', 'Genevieve', 'Georgiana', 'Ginevra',
    'Giselle', 'Guinevere', 'Gwendolyn', 'Harriet', 'Hazel', 'Helena', 'Henrietta',
    'Hermione', 'Honoria', 'Imelda', 'Imogen', 'Ingrid', 'Iris', 'Isadora', 'Ivy',
    'Josephine', 'Juniper', 'Lavinia', 'Lenora', 'Lilith', 'Lillian', 'Lorelei',
    'Lucinda', 'Lydia', 'Mabel', 'Maeve', 'Magnolia', 'Marceline', 'Mariana',
    'Marigold', 'Matilda', 'Millicent', 'Minerva', 'Mirabelle', 'Nora', 'Octavia',
    'Odette', 'Olive', 'Opal', 'Ophelia', 'Penelope', 'Persephone', 'Philomena',
    'Primrose', 'Prudence', 'Rosalind', 'Rosamund', 'Rowena', 'Scarlett', 'Seraphina',
    'Sophronia', 'Sylvia', 'Tabitha', 'Temperance', 'Theodora', 'Valentina', 'Veronica',
    'Victoria', 'Viola', 'Vivienne', 'Wilhelmina', 'Winifred', 'Winona', 'Zara', 'Zelda',
    'Zephyrine', 'Zinnia'
]

male_names = [
    'Alaric', 'Alastair', 'Algernon', 'Ambrose', 'Archibald', 'Atticus', 'Augustus',
    'Balthazar', 'Barnaby', 'Bartholomew', 'Basil', 'Benedict', 'Caspian', 'Cassius',
    'Cecil', 'Cedric', 'Clarence', 'Cornelius', 'Crispin', 'Cyrus', 'Dashiell', 'Dexter',
    'Dominic', 'Dorian', 'Edgar', 'Edmund', 'Edric', 'Edwin', 'Elias', 'Ephraim', 'Everard',
    'Ezekiel', 'Felix', 'Ferdinand', 'Finnegan', 'Fitzwilliam', 'Fletcher', 'Gabriel',
    'Gideon', 'Godfrey', 'Gulliver', 'Hamilton', 'Harrison', 'Hawthorne', 'Horatio', 'Hugo',
    'Humphrey', 'Ignatius', 'Isidore', 'Jareth', 'Jasper', 'Jeremiah', 'Jonathan', 'Kendrick',
    'Kingsley', 'Klaus', 'Lancaster', 'Lancelot', 'Lazarus', 'Leopold', 'Lysander', 'Maverick',
    'Maximilian', 'Maximus', 'Milo', 'Montgomery', 'Mortimer', 'Nathaniel', 'Nero', 'Neville',
    'Nigel', 'Oberon', 'Octavius', 'Oliver', 'Orlando', 'Orson', 'Percival', 'Peregrine', 'Phineas',
    'Quentin', 'Quilliam', 'Quincy', 'Rafferty', 'Randolph', 'Raphael', 'Reginald', 'Rufus', 'Rupert',
    'Rutherford', 'Salvador', 'Seamus', 'Sebastian', 'Silas', 'Simeon', 'Sullivan', 'Thaddeus',
    'Thelonious', 'Theodore', 'Tobias', 'Tristan', 'Ulrich', 'Ulysses', 'Upton', 'Uriah',
    'Valentine', 'Vesper', 'Victor', 'Virgil', 'Walter', 'Wellington', 'Wesley', 'Wilbur',
    'Wilfred', 'Winston', 'Wolfgang', 'Xander', 'Xavier', 'Yancy', 'Yardley', 'Yorick', 'Zachariah',
    'Zacharias', 'Zebediah', 'Zephyr', 'Zephyrus'
]

surnames = [
    "Ainsworth",
    "Aldington",
    "Aldridge",
    "Archer",
    "Ashburton",
    "Ashcroft",
    "Ashford",
    "Beauchamp",
    "Beaumont",
    "Blackburn",
    "Blackwood",
    "Blakeley",
    "Bradford",
    "Bradshaw",
    "Bromley",
    "Bromsgrove",
    "Buckingham",
    "Carrington",
    "Chadwick",
    "Chamberlain",
    "Chandler",
    "Channing",
    "Charleston",
    "Charlton",
    "Chatham",
    "Chesney",
    "Clarendon",
    "Copperfield",
    "Cromwell",
    "Cunningham",
    "Darcy",
    "Davenport",
    "Drakeford",
    "Dunhill",
    "Dunstan",
    "Ellington",
    "Ellsworth",
    "Everhart",
    "Fairchild",
    "Fairfax",
    "Farnsworth",
    "Fitzgerald",
    "Fitzroy",
    "Fitzwilliam",
    "Grantham",
    "Graves",
    "Gresham",
    "Griffith",
    "Grimm",
    "Hadley",
    "Hammersmith",
    "Hampton",
    "Hargreaves",
    "Harrington",
    "Hartford",
    "Hawkesworth",
    "Hawkswood",
    "Hawksworth",
    "Hawthorne",
    "Hazelwood",
    "Hemingway",
    "Holland",
    "Holliday",
    "Hollingsworth",
    "Holmes",
    "Huntington",
    "Huxley",
    "Huxtable",
    "Kensington",
    "Kingsford",
    "Kingsley",
    "Lancashire",
    "Lancaster",
    "Langdon",
    "Langley",
    "Linden",
    "Livingston",
    "Lockwood",
    "Maitland",
    "Montague",
    "Montgomery",
    "Parrish",
    "Pemberley",
    "Pembroke",
    "Pendleton",
    "Radburn",
    "Radcliffe",
    "Radley",
    "Ramsey",
    "Rutherford",
    "Standish",
    "Stanhope",
    "Stratford",
    "Stratton",
    "Sunderland",
    "Sutherland",
    "Templeton",
    "Tennyson",
    "Thackeray",
    "Thornfield",
    "Wadsworth",
    "Warrick",
    "Warrington",
    "Waverly",
    "Wellington",
    "Wentworth",
    "Weston",
    "Wetherby",
    "Whitfield",
    "Whitlock",
    "Whittington",
    "Whitworth",
    "Wilberforce",
    "Winchester",
    "Windsor",
    "Winslow",
    "Winthorpe",
    "Winthrop",
    "Witherspoon",
    "Wolcott",
    "Worthington",
    "Wycliffe",
]

female = choice(female_names)
male = choice(male_names)
surname = choice(surnames)